#ifdef E_TYPEDEFS
#else
#ifndef E_INT_CONFIG_IMC_IMPORT_H
#define E_INT_CONFIG_IMC_IMPORT_H

E_Win *e_int_config_imc_import(E_Config_Dialog *parent);
void e_int_config_imc_import_del(E_Win *win);
    
#endif
#endif
